Hyperparameter Optimization
===========================

Algorithms
----------

.. currentmodule:: aiaccel.hpo.algorithms

.. autosummary::
    :toctree: generated/

    NelderMeadAlgorism

Optuna Utilities
----------------

Samplers
~~~~~~~~

.. currentmodule:: aiaccel.hpo.optuna.samplers

.. autosummary::
    :toctree: generated/

    NelderMeadSampler

Suggest Wrappers
~~~~~~~~~~~~~~~~

.. currentmodule:: aiaccel.hpo.optuna.suggest_wrapper

.. autosummary::
    :toctree: generated/

    Suggest
    Const
    SuggestFloat
    SuggestInt
    SuggestCategorical
    SuggestDiscreteUniform
    SuggestLogUniform
    SuggestUniform

..
    lightning.OptimizerLightningModule

..
    lightning.OptimizerConfig
